Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(779)

Unified Diff: pkg/analyzer/lib/src/task/dart.dart

Issue 1165283006: Build full LIBRARY_ELEMENT for every library source in the import/export closure, when resolve a un… (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/analyzer/test/src/task/dart_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/task/dart.dart
diff --git a/pkg/analyzer/lib/src/task/dart.dart b/pkg/analyzer/lib/src/task/dart.dart
index a85273b604b34fd6beff5642664d108df1f1c0d9..7ec2d0ea93a17e9fdb75cfd30040f2405a504d85 100644
--- a/pkg/analyzer/lib/src/task/dart.dart
+++ b/pkg/analyzer/lib/src/task/dart.dart
@@ -243,7 +243,7 @@ final ResultDescriptor<LibraryElement> LIBRARY_ELEMENT4 =
/**
* The partial [LibraryElement] associated with a library.
*
* [LIBRARY_ELEMENT4] plus [RESOLVED_UNIT4] for every unit.
*
* The result is only available for [Source]s representing a library.
*/
@@ -3131,6 +3131,9 @@ class ResolveVariableReferencesTask extends SourceBasedAnalysisTask {
*/
static Map<String, TaskInput> buildInputs(LibrarySpecificUnit target) {
return <String, TaskInput>{
+ 'fullyBuiltLibraryElements': IMPORT_EXPORT_SOURCE_CLOSURE
+ .of(target.library)
+ .toListOf(LIBRARY_ELEMENT),
LIBRARY_INPUT: LIBRARY_ELEMENT.of(target.library),
UNIT_INPUT: RESOLVED_UNIT4.of(target),
TYPE_PROVIDER_INPUT: TYPE_PROVIDER.of(AnalysisContextTarget.request)
@@ -243,7 +243,7 @@ final ResultDescriptor<LibraryElement> LIBRARY_ELEMENT4 =
* The partial [LibraryElement] associated with a library.
*
- * [LIBRARY_ELEMENT4] plus [RESOLVED_UNIT4] for every unit.
+ * [LIBRARY_ELEMENT4] plus resolved types for every element.
*
* The result is only available for [Source]s representing a library.
« no previous file with comments | « no previous file | pkg/analyzer/test/src/task/dart_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698